# == Class: mercurial
#
# This module provides a class to manage mercurial.
#
# === Parameters
#
# [*ensure*]
#   Ensure if present, installed, absent, purged, held, latest, or a specific
#     version. Can only be 'present', 'installed', 'absent', or 'purged' if repo
#     is set.
#
#   Default: present
#
# [*repo*]
#   Id of the repository to install from. Only supported on RedHat-based
#   systems. The repository must be set up separately.
#
#   Default: 'base'
#
# === Examples
#
# To install mercurial:
#
#   class { 'mercurial': }
#
# To install mercurial from the rpmforge-extras repository from a RedHat-based
# system:
#
#   class { 'mercurial':
#     repo => 'rpmforge-extras',
#   }
#
# To remove mercurial:
#
#   class { 'mercurial':
#     ensure => 'absent',
#   }
#
# === License
#
# Copyright (C) 2013 Jeffrey Goettsch <jgoettsch@gmail.com>.
#
# This file is part of jgoettsch-mercurial.
#
# jgoettsch-mercurial is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# jgoettsch-mercurial is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with jgoettsch-mercurial.  If not, see <http://www.gnu.org/licenses/>.
#
class mercurial (
  $ensure = 'present',
  $repo = 'base',
) {

  if $repo != 'base' and !($ensure in ['present', 'installed', 'absent', 'purged']) {
    fail("\$ensure must only be 'present', 'installed', 'absent', or 'purged' when \$repo is set.")
  }

  if $repo != 'base' {
    case $::osfamily {
      'RedHat': {
        $repo_real = $repo
      }
      default:  {
        notice("The \$repo parameter is not supported on ${::osfamily} systems.")
        $repo_real = 'base'
      }
    }
  } else {
    $repo_real = 'base'
  }

  if $repo_real != 'base' and $ensure in ['present', 'installed'] {
    exec { 'yum install mercurial':
      command => "yum -y --enablerepo ${repo_real} install mercurial",
      unless  => "yum info mercurial | grep -i 'from repo' | awk '{print \$4}' | grep -qw ${repo_real}",
      path    => '/usr/bin:/bin',
    }
  } else {
    package { 'mercurial':
      ensure => $ensure,
    }
  }
}
